@@ -1,12 +1,14 @@
 from .classification import (
     Classification,
+)
+from .client import Dragoneye
+from .models import (
     ClassificationObjectPrediction,
     ClassificationPredictImageResponse,
     ClassificationTraitRootPrediction,
 )
-from .client import Dragoneye
 from .types.common import NormalizedBbox, TaxonID, TaxonPrediction, TaxonType
-from .types.image import Image
+from .types.media import Image, Video
 
 __all__ = [
     "Classification",
@@ -15,6 +17,7 @@ __all__ = [
     "ClassificationTraitRootPrediction",
     "Dragoneye",
     "Image",
+    "Video",
     "NormalizedBbox",
     "TaxonID",
     "TaxonPrediction",
