@@ -1,8 +1,11 @@
 from enum import Enum
-from typing import NewType, Optional, Sequence, Tuple
+from typing import Literal, NewType, Optional, Sequence, Tuple
 
 from pydantic import BaseModel
 
+PredictionType = Literal["image", "video"]
+PredictionTaskState = NewType("PredictionTaskState", str)
+
 NormalizedBbox = NewType("NormalizedBbox", Tuple[float, float, float, float])
 
 
@@ -13,6 +16,8 @@ class TaxonType(str, Enum):
 
 TaxonID = NewType("TaxonID", int)
 
+PredictionTaskUUID = NewType("PredictionTaskUUID", str)
+
 
 class TaxonPrediction(BaseModel):
     id: TaxonID
